/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.database.data;

import java.io.Serializable;
import java.util.Arrays;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Lob;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;

import org.apache.commons.lang3.StringUtils;

@Entity( name = "IconData" )
@Table( name = "dv_icon", uniqueConstraints = { @UniqueConstraint( columnNames = { "name" } ) } )
public class IconData
    implements Serializable
{

    private static final long serialVersionUID = 6074156785567152389L;

    public static final long NEW_ICON = 0;

    public static final long REMOVE_ICON_ID = -1;

    public static final long UNDEFINED_ICON = -1;

    public static final String DEFAULT_ICON = "vaadin:area-select";

    public static final String NEW_DATA = StringUtils.EMPTY;

    @Id
    @GeneratedValue( strategy = GenerationType.AUTO )
    private Long id;

    @Column( name = "name", length = 100, nullable = false )
    private String name;

    @Lob
    @Column( name = "icon", nullable = true )
    private byte[] icon;

    public IconData()
    {
        // nothing to do
    }

    public IconData( long id, String name, byte[] icon )
    {
        setId( id );
        setName( name );
        setIcon( icon );
    }

    public Long getId()
    {
        return id;
    }

    public void setId( Long id )
    {
        this.id = id;
    }

    public String getName()
    {
        return name;
    }

    public void setName( String name )
    {
        this.name = StringUtils.stripToEmpty( name );
    }

    public byte[] getIcon()
    {
        return icon;
    }

    public void setIcon( byte[] icon )
    {
        this.icon = icon;
    }

    @Override
    public int hashCode()
    {
        final int prime = 31;
        int result = 1;
        result = prime * result + Arrays.hashCode( icon );
        result = prime * result + ( ( id == null ) ? 0 : id.hashCode() );
        result = prime * result + ( ( name == null ) ? 0 : name.hashCode() );
        return result;
    }

    @Override
    public boolean equals( Object obj )
    {
        if ( this == obj )
        {
            return true;
        }
        if ( obj == null )
        {
            return false;
        }
        if ( !( obj instanceof IconData ) )
        {
            return false;
        }
        IconData other = (IconData) obj;
        if ( !Arrays.equals( icon, other.icon ) )
        {
            return false;
        }
        if ( id == null )
        {
            if ( other.id != null )
            {
                return false;
            }
        }
        else if ( !id.equals( other.id ) )
        {
            return false;
        }
        if ( name == null )
        {
            if ( other.name != null )
            {
                return false;
            }
        }
        else if ( !name.equals( other.name ) )
        {
            return false;
        }
        return true;
    }

}
