/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.info;

import java.io.Serializable;
import java.util.Arrays;
import java.util.List;

import org.dussan.vaadin.dvirtual.xpra.packets.base.ClientCapabilities;

public class ClientProperties
    implements Serializable
{

    private static final long serialVersionUID = 2633578730938636483L;

    public static final int DEFAULT_HEIGHT = 500;

    public static final int DEFAULT_WIDTH = 600;

    public static final int DPI = 96;

    private boolean macOS = false;

    private boolean webpEnabled = false;

    private boolean windowsOS = false;

    private int dpiValue = 0;

    private int height = 0;

    private int width = 0;

    private String colorGamut = null;

    public ClientProperties()
    {
        height = DEFAULT_HEIGHT;
        width = DEFAULT_WIDTH;
    }

    public void setClientProperties( int width, int height, Integer dpi, String colorGamut, boolean webpEnabled, boolean windowsOS, boolean macOS )
    {
        this.width = width;
        this.height = height;
        this.dpiValue = dpi == 0 ? DPI : dpi;
        this.colorGamut = colorGamut;
        this.webpEnabled = webpEnabled;
        this.windowsOS = windowsOS;
        this.macOS = macOS;
    }

    public boolean isMacOS()
    {
        return macOS;
    }

    public boolean isWebpEnabled()
    {
        return webpEnabled;
    }

    public boolean isWindowsOS()
    {
        return windowsOS;
    }

    public int getDpi()
    {
        return dpiValue;
    }

    public int getHeight()
    {
        return height;
    }

    public int getWidth()
    {
        return width;
    }

    public String getColorGamut()
    {
        return colorGamut;
    }

    public static List<?> getScreenSizes( int screenWidth, int screenHeight, int dpi )
    {
        int mmScreenWidth = (int) Math.round( screenWidth * ClientCapabilities.DPI_FACTOR / dpi );
        int mmScreenHeight = (int) Math.round( screenHeight * ClientCapabilities.DPI_FACTOR / dpi );
        List<?> monitorSize = Arrays.asList( ClientCapabilities.SCREEN_CANVAS, 0, 0, screenWidth, screenHeight, mmScreenWidth, mmScreenHeight );
        List<?> screenSize = Arrays.asList( ClientCapabilities.SCREEN_HTML, screenWidth, screenHeight, mmScreenWidth, mmScreenHeight, Arrays.asList( monitorSize ), 0, 0, screenWidth, screenHeight );
        return Arrays.asList( screenSize );
    }

}
