/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.runners;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.TimeUnit;

import org.dussan.vaadin.dvirtual.client.VirtualClient;
import org.dussan.vaadin.dvirtual.xpra.packets.client.ClientCloseWindowPacket;
import org.dussan.vaadin.dvirtual.xpra.window.Window;

public class CloseWindowsRunner
    implements Runnable
{

    private static final int SLEEP_CLOSE_WINDOW_INTERVAL = 700; // milliseconds

    private VirtualClient virtualClient = null;

    public CloseWindowsRunner( VirtualClient virtualClient )
    {
        this.virtualClient = virtualClient;
    }

    @Override
    public void run()
    {
        if ( Objects.nonNull( virtualClient ) && Objects.nonNull( virtualClient.getSender() ) )
        {
            List<Window> windows = new ArrayList<Window>( virtualClient.getWindows() );

            // close all dialog windows first
            windows.stream()
                   .filter( widow -> virtualClient.isDialogWindow( widow ) )
                   .forEach( window -> {
                       try
                       {
                           virtualClient.getSender()
                                        .onSend( new ClientCloseWindowPacket( window.getId() ) );
                           TimeUnit.MILLISECONDS.sleep( SLEEP_CLOSE_WINDOW_INTERVAL );
                       }
                       catch ( InterruptedException exception )
                       {
                           Thread.currentThread()
                                 .interrupt();
                       }
                   } );

            // close all other windows
            windows.stream()
                   .filter( widow -> virtualClient.isNotDialogWindow( widow ) )
                   .forEach( window -> {
                       try
                       {
                           virtualClient.getSender()
                                        .onSend( new ClientCloseWindowPacket( window.getId() ) );
                           TimeUnit.MILLISECONDS.sleep( SLEEP_CLOSE_WINDOW_INTERVAL );
                       }
                       catch ( InterruptedException exception )
                       {
                           Thread.currentThread()
                                 .interrupt();
                       }
                   } );
        }
    }

}
