/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.utils;

import java.io.Serializable;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

public class EnvironmentUtil
    implements Serializable
{

    private static final long serialVersionUID = 5456109663202713467L;

    private static final String ENV_LOOKUP = "java:comp/env";

    private EnvironmentUtil()
    {
        // nothing to do
    }

    public static final Boolean readBooleanEnvEntry( String envEntry )
    {
        Boolean envValue = null;
        try
        {
            Context context = new InitialContext();
            Context envContext = (Context) context.lookup( ENV_LOOKUP );
            envValue = (Boolean) envContext.lookup( envEntry );
        }
        catch ( NamingException exception )
        {
            // nothing to do
        }
        return envValue;
    }

    public static final int readIntegerEnvEntry( String envEntry )
    {
        int envValue = 0;
        try
        {
            Context context = new InitialContext();
            Context envContext = (Context) context.lookup( ENV_LOOKUP );
            envValue = (Integer) envContext.lookup( envEntry );
        }
        catch ( NamingException exception )
        {
            // nothing to do
        }
        return envValue;
    }

    public static final String readStringEnvEntry( String envEntry )
    {
        String envValue = null;
        try
        {
            Context context = new InitialContext();
            Context envContext = (Context) context.lookup( ENV_LOOKUP );
            envValue = (String) envContext.lookup( envEntry );
        }
        catch ( NamingException exception )
        {
            // nothing to do
        }
        return envValue;
    }

}
