/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.io.lz4;

import java.io.EOFException;
import java.io.IOException;
import java.io.InputStream;

import org.apache.commons.compress.compressors.lz4.BlockLZ4CompressorInputStream;
import org.dussan.vaadin.dvirtual.utils.LoggerUtil;
import org.slf4j.Logger;

public class ChunkLz4InputStream
    extends BlockLZ4CompressorInputStream
{

    private static final Logger LOGGER = LoggerUtil.getLogger();

    private static final String NEGATIVE_SKIP_LENGTH = "Negative skip length.";

    private static final String UNEXPECTED_END_OF_INPUT_STREAM = "Unexpected end of input stream.";

    private int bytesToDrain = 0;

    public ChunkLz4InputStream( InputStream inputStream, int size )
        throws IOException
    {
        super( inputStream );
        this.bytesToDrain = size;
    }

    public void drain()
        throws IOException
    {
        if ( bytesToDrain < 0 )
        {
            LOGGER.error( NEGATIVE_SKIP_LENGTH );
            throw new IllegalArgumentException( NEGATIVE_SKIP_LENGTH );
        }

        int toRead = (int) ( bytesToDrain - getBytesRead() );
        byte[] buf = new byte[toRead];
        while ( toRead > 0 )
        {
            int len = toRead;
            if ( len > buf.length )
            {
                len = buf.length;
            }

            len = read( buf, 0, len );
            if ( len < 0 )
            {
                LOGGER.error( UNEXPECTED_END_OF_INPUT_STREAM );
                throw new EOFException( UNEXPECTED_END_OF_INPUT_STREAM );
            }
            toRead -= len;
        }
    }

}
