/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.io.rencode;

import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;

/**
 * Rencode type codes forked from rencode-java.
 * 
 * @see {@linkplain https://github.com/jksiezni/rencode4j/}
 */
class Rencode
{

    public static final Charset UTF_8 = StandardCharsets.UTF_8;

    // Default number of bits for serialized floats,
    // either 32 or 64 (also a parameter for dumps()).
    public static final int LENGTH_DELIMITER = ':';

    // Maximum length of integer when written as base 10 string.
    public static final int MAX_INT_LENGTH = 64;

    // The bencode 'typecodes' such as integer, dictionary, etc
    // have been extended and relocated on the base-256 character set.
    public static final int CHAR_DICT = 60;

    public static final int CHAR_FALSE = 68;

    public static final int CHAR_FLOAT32 = 66;

    public static final int CHAR_FLOAT64 = 44;

    public static final int CHAR_INT = 61;

    public static final int CHAR_INT1 = 62;

    public static final int CHAR_INT2 = 63;

    public static final int CHAR_INT4 = 64;

    public static final int CHAR_INT8 = 65;

    public static final int CHAR_LIST = 59;

    public static final int CHAR_NONE = 69;

    public static final int CHAR_TERMINATION = 127;

    public static final int CHAR_TRUE = 67;

    // Dictionaries with length embedded in typecode.
    public static final int DICTIONARY_FIXED_COUNT = 25;

    public static final int DICTIONARY_FIXED_START = 102;

    // Negative integers with value embedded in typecode.
    public static final int INT_NEG_FIXED_COUNT = 32;

    public static final int INT_NEG_FIXED_START = 70;

    // Positive integers with value embedded in typecode.
    public static final int INT_POS_FIXED_COUNT = 44;

    public static final int INT_POS_FIXED_START = 0;

    // Strings with length embedded in typecode.
    public static final int STRING_FIXED_START = 128;

    public static final int STRING_FIXED_COUNT = 64;

    // Lists with length embedded in typecode.
    public static final int LIST_FIXED_START = STRING_FIXED_START + STRING_FIXED_COUNT;

    public static final int LIST_FIXED_COUNT = 64;

    private Rencode()
    {
        // nothing to do
    }

}
