/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.xpra.packets.base;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Objects;

import org.apache.commons.lang3.StringUtils;

public enum ClipboardTarget
{

    UTF8_STRING( "UTF8_STRING" ), TEXT( "TEXT" ), STRING( "STRING" ), TEXT_PLAIN( "textplain" );

    private String target;

    private ClipboardTarget()
    {
        target = name();
    }

    ClipboardTarget( String target )
    {
        this.target = target;
    }

    public static ClipboardTarget getTarget( String target )
    {
        for ( ClipboardTarget clipboardTarget : ClipboardTarget.values() )
        {
            if ( StringUtils.equals( clipboardTarget.toString(), target ) )
            {
                return clipboardTarget;
            }
        }
        return null;
    }

    public static ClipboardTarget[] getAllTargets()
    {
        List<ClipboardTarget> targets = new ArrayList<>();
        for ( ClipboardTarget target : ClipboardTarget.values() )
        {
            Collections.addAll( targets, target );
        }
        return targets.toArray( ClipboardTarget[]::new );
    }

    public static List<String> toStringList( ClipboardTarget[] targets )
    {
        List<String> targetList = new ArrayList<>();
        if ( Objects.nonNull( targets ) && targets.length > 0 )
        {
            for ( ClipboardTarget target : targets )
            {
                targetList.add( target.toString() );
            }
        }
        return targetList;
    }

    @Override
    public String toString()
    {
        return target;
    }

}
