/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets.client;

import java.util.Collection;

import org.dussan.vaadin.dvirtual.xpra.packets.ClientPacket;
import org.dussan.vaadin.dvirtual.xpra.packets.PacketType;

public class ClientClipboardContentsPacket
    extends ClientPacket
{

    private static final long serialVersionUID = -960112454858527L;

    private static final int BYTES_LENGTH = 8;

    private static final String BYTES = "bytes";

    private static final String UTF8_STRING = "UTF8_STRING";

    private int requestId = 0;

    private String clipboardData = null;

    private String selection = null;

    public ClientClipboardContentsPacket()
    {
        super( PacketType.Client.CLIPBOARD_CONTENTS.toString() );
    }

    public ClientClipboardContentsPacket( int requestId, String selection, String clipboardData )
    {
        super( PacketType.Client.CLIPBOARD_CONTENTS.toString() );
        this.requestId = requestId;
        this.selection = selection;
        this.clipboardData = clipboardData;
    }

    public int getRequestId()
    {
        return requestId;
    }

    public String getClipboardData()
    {
        return clipboardData;
    }

    public String getSelection()
    {
        return selection;
    }

    @Override
    public void packPacket( Collection<Object> packetData )
    {
        packetData.add( getPacketType() );
        packetData.add( getRequestId() );
        packetData.add( getSelection() );
        packetData.add( UTF8_STRING );
        packetData.add( BYTES_LENGTH );
        packetData.add( BYTES );
        packetData.add( getClipboardData() );
    }

}
