/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets.client;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.dussan.vaadin.dvirtual.xpra.packets.ClientPacket;
import org.dussan.vaadin.dvirtual.xpra.packets.PacketType;

public class ClientPointerPositionPacket
    extends ClientPacket
{

    private static final long serialVersionUID = -9155440005344265502L;

    private int windowId = 0;

    private List<Integer> buttons = new ArrayList<>();

    private List<Integer> pointerPosition = new ArrayList<>( 2 );

    private List<String> modifiers = new ArrayList<>();

    public ClientPointerPositionPacket()
    {
        super( PacketType.Client.POINTER_POSITION.toString() );
    }

    public ClientPointerPositionPacket( int windowId, int x, int y, List<String> modifiers )
    {
        super( PacketType.Client.POINTER_POSITION.toString() );
        this.windowId = windowId;
        this.modifiers = modifiers;
        pointerPosition.add( x );
        pointerPosition.add( y );
    }

    public int getWindowId()
    {
        return windowId;
    }

    public List<Integer> getButtons()
    {
        return buttons;
    }

    public List<Integer> getPointerPosition()
    {
        return pointerPosition;
    }

    public List<String> getModifiers()
    {
        return modifiers;
    }

    @Override
    public void packPacket( Collection<Object> packetData )
    {
        packetData.add( getPacketType() );
        packetData.add( getWindowId() );
        packetData.add( getPointerPosition() );
        packetData.add( getModifiers() );
        packetData.add( getButtons() );
    }

}
