/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets.server;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.dussan.vaadin.dvirtual.xpra.packets.ServerPacket;
import org.dussan.vaadin.dvirtual.xpra.packets.PacketType;

public class ServerClipboardTokenPacket
    extends ServerPacket
{

    private static final long serialVersionUID = -639649181762398264L;

    private String clipboardData = null;

    private String clipboardTarget = null;

    public ServerClipboardTokenPacket()
    {
        super( PacketType.Server.CLIPBOARD_TOKEN.toString() );
    }

    public String getClipboardData()
    {
        return clipboardData;
    }

    public String getClipboardTarget()
    {
        return clipboardTarget;
    }

    @Override
    public void unpackPacket( Iterator<Object> packetData )
    {
        super.unpackPacket( packetData );

        List<Object> packetDataList = new ArrayList<>();
        packetData.forEachRemaining( packetDataList::add );
        if ( packetDataList.size() >= 7 )
        {
            clipboardTarget = getString( packetDataList.get( 2 ) );
            clipboardData = getString( packetDataList.get( 6 ) );
        }
    }

}
