/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets.server;

import java.util.Iterator;
import org.dussan.vaadin.dvirtual.xpra.packets.PacketType;
import org.dussan.vaadin.dvirtual.xpra.packets.ServerPacket;

public class ServerDesktopSizePacket
    extends ServerPacket
{

    private static final long serialVersionUID = -910236760089966827L;

    private int height = 0;

    private int maxHeight = 0;

    private int maxWidth = 0;

    private int width = 0;

    private int windowId = 0;

    public ServerDesktopSizePacket()
    {
        super( PacketType.Server.DESKTOP_SIZE.toString() );
    }

    public ServerDesktopSizePacket( int windowId, int width, int height, int maxWidth, int maxHeight )
    {
        super( PacketType.Server.DESKTOP_SIZE.toString() );
        this.windowId = windowId;
        this.width = width;
        this.height = height;
        this.maxWidth = maxWidth;
        this.maxHeight = maxHeight;
    }

    public int getWindowId()
    {
        return windowId;
    }

    public int getX()
    {
        return maxWidth;
    }

    public int getY()
    {
        return maxHeight;
    }

    public int getWidth()
    {
        return width;
    }

    public int getHeight()
    {
        return height;
    }

    @Override
    public void unpackPacket( Iterator<Object> packetData )
    {
        super.unpackPacket( packetData );
        windowId = getInt( packetData.next() );
        width = getInt( packetData.next() );
        height = getInt( packetData.next() );
        maxWidth = getInt( packetData.next() );
        maxHeight = getInt( packetData.next() );
    }

}
