/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual;

import static org.junit.Assert.assertTrue;

import java.io.File;
import java.util.Objects;

import org.apache.commons.lang3.StringUtils;
import org.dussan.vaadin.dvirtual.config.DVirtualConfig;
import org.dussan.vaadin.dvirtual.info.ApplicationLocale;
import org.dussan.vaadin.dvirtual.info.KeyboardLayout;
import org.dussan.vaadin.dvirtual.info.TranslationLocale;
import org.junit.BeforeClass;
import org.junit.Test;

public class DVirtualConfTest
{

    private static final int TEST_SESSION_TIMEOUT = 1800;

    private static final boolean TEST_ALL_RUNNING_IN_SAME_INSTANCE = false;

    private static final boolean TEST_APPLICATIONS_BAR_VISIBLE = true;

    private static final boolean TEST_STARTUP_NOTIFICATION_VISIBLE = true;

    private static final boolean TEST_TOOLTIP_VISIBLE = true;

    private static final String DVIRTUAL_CONF_FILENAME = "dvirtual.conf";

    private static final String ERROR_INITIALIZATION = "dVirtual is not initialized.";

    private static final String ERROR_VALUE = "Wrong value.";

    private static final String FOLDER_SEPARATOR = File.separator;

    private static final String RESOURCE_FOLDER = String.join( FOLDER_SEPARATOR, "src", "test", "resources" );

    private static final String TEST_ADMIN_CONFIG = "admin.conf";

    private static final String TEST_APPLICATION_CONFIG = "application.conf";

    private static final String TEST_APPLICATION_GROUP_CONFIG = "applications_group.conf";

    private static final String TEST_APPLICATION_LOCALE = "en_US";

    private static final String TEST_DATABASE_CONFIG = "database.conf";

    private static final String TEST_KEYBOARD_LAYOUT = "us";

    private static final String TEST_LOGIN_TITLE = "dVirtual Log in";

    private static final String TEST_SALT = "6cR8CNHtZgm4AfaQ5bg5RzN7DU8FXNfz";

    private static final String TEST_SALT_IV = "2AD9AKRPAbcN";

    private static final String TEST_SALT_KEY = "vRZ4XPUuDWqNQGhMnyP927TLmXKkFmp9";

    private static final String TEST_SERVER_CONFIG = "server.conf";

    private static final String TEST_SERVERS_GROUP_CONFIG = "servers_group.conf";

    private static final String TEST_TRANSLATION_LOCALE = "en_US";

    private static final String TEST_USER_CONFIG = "user.conf";

    private static DVirtualConfig dVirtualConfig = null;

    @BeforeClass
    public static void init()
    {
        dVirtualConfig = new DVirtualConfig( RESOURCE_FOLDER, DVIRTUAL_CONF_FILENAME );
    }

    @Test
    public void dVitualConf()
    {
        assertTrue( ERROR_INITIALIZATION, dVirtualConfig.isInitialized() );
    }

    @Test
    public void salt()
    {
        assertTrue( ERROR_VALUE, StringUtils.equals( dVirtualConfig.getSalt(), TEST_SALT ) );
    }

    @Test
    public void saltKey()
    {
        assertTrue( ERROR_VALUE, StringUtils.equals( dVirtualConfig.getSaltKey(), TEST_SALT_KEY ) );
    }

    @Test
    public void saltIV()
    {
        assertTrue( ERROR_VALUE, StringUtils.equals( dVirtualConfig.getSaltIV(), TEST_SALT_IV ) );
    }

    @Test
    public void sessionTimeout()
    {
        assertTrue( ERROR_VALUE, Objects.equals( dVirtualConfig.getSessionTimeout(), TEST_SESSION_TIMEOUT ) );
    }

    @Test
    public void keyboardLayout()
    {
        assertTrue( ERROR_VALUE, Objects.equals( dVirtualConfig.getKeyboardLayout(), KeyboardLayout.getKeyboardLayout( TEST_KEYBOARD_LAYOUT ) ) );
    }

    @Test
    public void applicationLocale()
    {
        assertTrue( ERROR_VALUE, Objects.equals( dVirtualConfig.getApplicationLocale(), ApplicationLocale.getApplicationLocale( TEST_APPLICATION_LOCALE ) ) );
    }

    @Test
    public void translationLocale()
    {
        assertTrue( ERROR_VALUE, Objects.equals( dVirtualConfig.getTranslationLocale(), TranslationLocale.getTranslationLocale( TEST_TRANSLATION_LOCALE ) ) );
    }

    @Test
    public void loginTitle()
    {
        assertTrue( ERROR_VALUE, StringUtils.equals( dVirtualConfig.getLoginTitle(), TEST_LOGIN_TITLE ) );
    }

    @Test
    public void allRunningInSameInstance()
    {
        assertTrue( ERROR_VALUE, dVirtualConfig.isAllRunningInSameInstance() == TEST_ALL_RUNNING_IN_SAME_INSTANCE );
    }

    @Test
    public void applicationsBarVisible()
    {
        assertTrue( ERROR_VALUE, dVirtualConfig.isApplicationsBarVisible() == TEST_APPLICATIONS_BAR_VISIBLE );
    }

    @Test
    public void startupNotificationVisible()
    {
        assertTrue( ERROR_VALUE, dVirtualConfig.isStartupNotificationsVisible() == TEST_STARTUP_NOTIFICATION_VISIBLE );
    }

    @Test
    public void tooltipVisible()
    {
        assertTrue( ERROR_VALUE, dVirtualConfig.isTooltipsVisible() == TEST_TOOLTIP_VISIBLE );
    }

    @Test
    public void adminConf()
    {
        assertTrue( ERROR_VALUE, StringUtils.equals( dVirtualConfig.getAdminConfig(), TEST_ADMIN_CONFIG ) );
    }

    @Test
    public void databaseConfig()
    {
        assertTrue( ERROR_VALUE, StringUtils.equals( dVirtualConfig.getDatabaseConfig(), TEST_DATABASE_CONFIG ) );
    }

    @Test
    public void applicationConfig()
    {
        assertTrue( ERROR_VALUE, StringUtils.equals( dVirtualConfig.getApplicationConfig(), TEST_APPLICATION_CONFIG ) );
    }

    @Test
    public void applicationGroupConfig()
    {
        assertTrue( ERROR_VALUE, StringUtils.equals( dVirtualConfig.getApplicationsGroupConfig(), TEST_APPLICATION_GROUP_CONFIG ) );
    }

    @Test
    public void serverConfig()
    {
        assertTrue( ERROR_VALUE, StringUtils.equals( dVirtualConfig.getServerConfig(), TEST_SERVER_CONFIG ) );
    }

    @Test
    public void serversGroupConfig()
    {
        assertTrue( ERROR_VALUE, StringUtils.equals( dVirtualConfig.getServersGroupConfig(), TEST_SERVERS_GROUP_CONFIG ) );
    }

    @Test
    public void userConfig()
    {
        assertTrue( ERROR_VALUE, StringUtils.equals( dVirtualConfig.getUserConfig(), TEST_USER_CONFIG ) );
    }

}
